@@ -143,6 +143,12 @@ public:
      */
     virtual QString fileName() const = 0;
 
+    /**
+     * Returns the path of the local repository root for the versionned directory
+     * Returns an emtpy QString when directory is not part of a working copy
+     */
+    virtual QString localRepositoryRoot(const QString& directory) const;
+
     /**
      * Is invoked whenever the version control
      * information will get retrieved for the directory
@@ -177,6 +183,7 @@ public:
      * @return List of actions that are available for the out of version control
      *         items \p items. It's opposed to the \p versionedActions. Common usage
      *         is for clone/checkout actions.
+     * @since 21.04
      */
     virtual QList<QAction*> outOfVersionControlActions(const KFileItemList& items) const = 0;
 
